import { Color, Node, Sprite, SpriteFrame } from 'cc';

/**
 * Base class for Grips extends Node.<br/>
 *
 * Comes with grip related functionalities and properties.
 */
export class Grip extends Node {
  private inner!: Node;
  private outer!: Node;

  private innerSprite!: Sprite;
  private outerSprite!: Sprite;

  constructor(
    innerSpriteFrame: SpriteFrame,
    outerSpriteFrame: SpriteFrame,
    name: string | undefined = 'grip'
  ) {
    super(name);

    this.inner = new Node('inner');
    this.innerSprite = this.inner.addComponent(Sprite);
    this.innerSprite.spriteFrame = innerSpriteFrame;

    this.outer = new Node('outer');
    this.outerSprite = this.outer.addComponent(Sprite);
    this.outerSprite.spriteFrame = outerSpriteFrame;

    this.addChild(this.outer);
    this.addChild(this.inner);

    this.changeColor('#ff0000', '#00ff00');
  }

  changeColor(innerColor: string, outerColor: string): void {
    this.innerSprite.color = new Color().fromHEX(innerColor);
    this.outerSprite.color = new Color().fromHEX(outerColor);
  }
}
